context property
Narrows the type of the stateful context for consumers.
Implementation
@override
StatefulElement get context => super.context as StatefulElement;
Narrows the type of the stateful context for consumers.
@override
StatefulElement get context => super.context as StatefulElement;