readyState method

  1. @visibleForOverriding
  2. @protected
void readyState()
inherited

Called after the first frame when the widget is mounted.

Use this hook for logic that needs a fully initialized element tree, such as interacting with inherited widgets or routing APIs. Subclasses should override this method instead of didChangeDependencies.

Implementation

@visibleForOverriding
@protected
void readyState() {}