KeepAliveStateMixin<T extends StateWidget<State<StatefulWidget> > > mixin
Provides AutomaticKeepAliveClientMixin wiring for StateControllers.
class RootPageController extends StateController<RootPage>
with KeepAliveStateMixin {
// Optionally override `keepAlive` to toggle the behavior dynamically.
}
When used, the controller becomes responsible for driving the widget build
through buildWithStateWidget. The default implementation simply delegates
to widget.build(context) while ensuring that the keep-alive handle is kept
up to date.
- Superclass constraints
- Implemented types
Properties
- context → StatefulElement
-
Narrows the type of the stateful context for consumers.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepAlive → bool
-
Whether the associated subtree should be kept alive.
no setter
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wantKeepAlive → bool
-
no setter
- widget → T
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Throws to prevent UI building from the controller.
inherited
-
buildWithStateWidget(
BuildContext context) → Widget -
Called by the framework when the widget associated with this controller
should build.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
override
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant T oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Provides initialization hooks for subclasses.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readyState(
) → void -
Called after the first frame when the widget is mounted.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
updateKeepAlive(
) → void -
Ensures any
AutomaticKeepAliveancestors stay in sync with keepAlive.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited